# SecureAgent

The secure agent. This determines how an agent can expose internal applications to the public internet
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**metadata** | [**MetadataWithId**](MetadataWithId.md) |  | [optional] 
**spec** | [**SecureAgentSpec**](SecureAgentSpec.md) |  | 
**status** | [**SecureAgentStatus**](SecureAgentStatus.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


